@@ -5,7 +5,8 @@ import os
 import re
 import sys
 
-from clu.constants import ENCODING, lru_cache
+from clu.constants.consts import ENCODING
+from clu.constants.polyfills import lru_cache
 from clu.typology import string_types
 from clu.exporting import Exporter
 
