@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
 
-from .ansi import (print_separator, print_ansi, print_ansi_centered, ansidoc, highlight)
+from .ansi import (print_separator, evict_announcer, print_ansi, print_ansi_centered, ansidoc, highlight)
 from .ansi import (ANSIBase, ANSI, Text, Weight, Background, ANSIFormat)
 from .banners import (banners, is_python2_dead, print_python_banner, print_warning, print_banner)
 
-__all__ = ('print_separator',
+__all__ = ('print_separator', 'evict_announcer',
            'print_ansi', 'print_ansi_centered',
            'ansidoc', 'highlight',
            'ANSIBase', 'ANSI',
